# Horus Media Server Client

An [Horus Media Server](https://horus.nu/horus-geo-suite/) client python library

## [Install latest release](https://github.com/horus-view-and-explore/horus-media-client/wiki/Install-latest-release)


## [Run the example strategy](https://github.com/horus-view-and-explore/horus-media-client/wiki/Example-strategy-tool)

```
python3 -m horus_media_examples.example_strategy --help
```
